Package: scMultiome
Title: Collection of Public Single-Cell Multiome (scATAC + scRNAseq)
        Datasets
Version: 1.10.0
Authors@R: c(
    person(given = "Xiaosai", family ="Yao", email = "xiaosai.yao@gmail.com", role = c("cre","aut"),  comment = c(ORCID = "0000-0001-9729-0726")),
    person(given = "Aleksander", family ="Chlebowski", email = "aleksander.chlebowski@contractors.roche.com", role = "aut"),
    person(given = "Aaron", family ="Lun", email = "lun.aaron@gene.com", role = "aut"),
    person(given = "Shiqi", family ="Xie", email = "xie.shiqi@gene.com", role = "ctb"),
    person(given = "Tomasz", family = "Włodarczyk", email = "tomasz.wlodarczyk@contractors.roche.com", role = "aut")
  )
Description: Single cell multiome data, containing chromatin accessibility
    (scATAC-seq) and gene expression (scRNA-seq) information analyzed with
    the ArchR package and presented as MultiAssayExperiment objects.
License: CC BY-SA 4.0
Depends: AnnotationHub, ExperimentHub (>= 2.8.1), MultiAssayExperiment,
        SingleCellExperiment, SummarizedExperiment
Imports: AzureStor, GenomicRanges, HDF5Array, S4Vectors, checkmate,
        methods, rhdf5, alabaster.matrix
Suggests: BiocGenerics, IRanges, Matrix, knitr, rmarkdown, rstudioapi,
        testthat (>= 3.0.0), devtools, BiocStyle, ExperimentHubData
VignetteBuilder: knitr
Config/testthat/edition: 3
Encoding: UTF-8
Roxygen: list(markdown = TRUE)
RoxygenNote: 7.3.2
biocViews: PackageTypeData, ExperimentHub, SingleCellData,
        ExpressionData, SequencingData, Homo_sapiens_Data, CellCulture,
        Tissue, GEO
git_url: https://git.bioconductor.org/packages/scMultiome
git_branch: RELEASE_3_22
git_last_commit: 26da406
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
NeedsCompilation: no
Packaged: 2025-11-04 16:42:45 UTC; biocbuild
Author: Xiaosai Yao [cre, aut] (ORCID: <https://orcid.org/0000-0001-9729-0726>),
  Aleksander Chlebowski [aut],
  Aaron Lun [aut],
  Shiqi Xie [ctb],
  Tomasz Włodarczyk [aut]
Maintainer: Xiaosai Yao <xiaosai.yao@gmail.com>
