# Generated by roxygen2: do not edit by hand

export(AR_drug)
export(PBMC_10x)
export(TEADi_resistance)
export(assertHDF5)
export(colonHealthy)
export(dummyMAE)
export(dummySCE)
export(hematopoiesis)
export(listDatasets)
export(loadExp)
export(loadMAE)
export(prostateENZ)
export(reprogramSeq)
export(saveExp)
export(saveMAE)
export(testFile)
export(tfBinding)
export(tfMotifs)
export(uploadFile)
exportMethods(saveExp)
import(AnnotationHub)
import(ExperimentHub)
import(MultiAssayExperiment)
import(SingleCellExperiment)
import(SummarizedExperiment)
