
# The purpose of this script is to describe how all datasets were obtained.

### Excerpt from ExperimentHub's vignette:
# A script describing the steps involved in making the data object(s).
# It can be code, pseudo-code, or text but should include
# where the original data were downloaded from, pre-processing, and how the final R object was made.
# Include a description of any steps performed outside of R with third party software.
# Output of the [process described in the] script should be files on disk ready to be pushed to data server.
###

# The creation of all datasets is described in detail in respective help files.
# Run listDatasets() or ?scMultiome to view a list of available datasets.
# See ?<DATASET_NAME> for details on particular datasets, e.g. ?prostateENZ.
