---
title: "Data Set List"
output:
  BiocStyle::html_document:
    titlecaps: false
    toc_float: true
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(echo = TRUE, eval = FALSE)
```

+ **AR_drug**: Response of prostate cancer cells to drug treatment
+ **colonHealthy**: Single-cell analysis of samples from healthy human colon
+ **hematopoiesis**: scATAC-seq and unpaired scRNA-seq of hematopoetic cells
+ **PBMC_10x**: PBMC Data Set
+ **prostateENZ**: LNCaP Cells Treated with Enzalutamide
+ **reprogramSeq**: Reprogram-seq of LNCaP cells
+ **TEADi_resistance**: Resistance of TEAD inhibitor to drug
+ **tfBinding_hg19_atlas**: TF Binding Info hg19 (ChIP-Atlas and ENCODE)
+ **tfBinding_hg19_atlas.sample**: TF Binding Info hg19 by sample (ChIP-Atlas)
+ **tfBinding_hg19_atlas.sample_v2**: TF Binding Info hg19 by sample (ChIP-Atlas)
+ **tfBinding_hg19_atlas.tissue**: TF Binding Info hg19 by tissue (ChIP-Atlas)
+ **tfBinding_hg19_atlas.tissue_v2**: TF Binding Info hg19 by tissue (ChIP-Atlas)
+ **tfBinding_hg19_encode.sample**: TF Binding Info hg19 by sample (ENCODE)
+ **tfBinding_hg19_encode.sample_v2**: TF Binding Info hg19 by sample (ENCODE)
+ **tfBinding_hg38_atlas**: TF Binding Info hg38 (ChIP-Atlas and ENCODE)
+ **tfBinding_hg38_atlas.sample**: TF Binding Info hg38 by sample (ChIP-Atlas)
+ **tfBinding_hg38_atlas.sample_v2**: TF Binding Info hg38 by sample (ChIP-Atlas)
+ **tfBinding_hg38_atlas.tissue**: TF Binding Info hg38 by tissue (ChIP-Atlas)
+ **tfBinding_hg38_atlas.tissue_v2**: TF Binding Info hg38 by tissue (ChIP-Atlas)
+ **tfBinding_hg38_encode.sample**: TF Binding Info hg38 by sample (ENCODE)
+ **tfBinding_hg38_encode.sample_v2**: TF Binding Info hg38 by sample (ENCODE)
+ **tfBinding_mm10_atlas**: TF Binding Info mm10 (ChIP-Atlas and ENCODE)
+ **tfBinding_mm10_atlas.sample**: TF Binding Info mm10 by sample (ChIP-Atlas)
+ **tfBinding_mm10_atlas.sample_v2**: TF Binding Info mm10 by sample (ChIP-Atlas)
+ **tfBinding_mm10_atlas.tissue**: TF Binding Info mm10 by tissue (ChIP-Atlas)
+ **tfBinding_mm10_atlas.tissue_v2**: TF Binding Info mm10 by tissue (ChIP-Atlas)
+ **tfBinding_mm10_encode.sample**: TF Binding Info mm10 by sample (ENCODE)
+ **tfBinding_mm10_encode.sample_v2**: TF Binding Info mm10 by sample (ENCODE)
+ **human_pwms_v2**: TF motifs human
+ **mouse_pwms_v2**: TF motifs mouse

